import logging
from collection import *


class Collections(object):
    def __init__(self):
        self.orderedArray = []
        self.collectionObjects = {}
        self.dirty = False
        self.loaded = False

    def __len__(self):
        return len(self.collectionObjects)

    def __getitem__(self, collectionKey):
        if collectionKey in self.collectionObjects:
            return self.collectionObjects[collectionKey]
        else:
            raise KeyError

    def __setitem__(self, collectionKey, item):
        self.collectionObjects[collectionKey] = item

    def __delitem__(self, collectionKey):
        del self.collectionObjects[collectionKey]

    def __iter__(self):
        return self.collectionObjects.__iter__()

    def __reversed__(self):
        ritems = Items()
        ritems.collectionObjects = self.collectionObjects.reversed()
        return ritems

    def __contains__(self, collectionKey):
        return collectionKey in self.collectionObjects

    def addCollection(self, collection):
        self.collectionObjects[collection.collectionKey] = collection
        self.orderedArray.append(collection)

    def getCollection(self, collectionKey):
        if collectionKey in self.collectionObjects:
            return self.collectionObjects[collectionKey]
        else:
            return False

    def addCollectionsFromFeed(self, feed):
        addedCollections = []
        for entry in feed.entries:
            collection = Collection(entry)
            self.addCollection(collection)
            addedCollections.append(collection)

        return addedCollections

    def nestCollections(self):
        pass

    def orderCollections(self):
        pass

    def topCollectionKeys(self):
        pass



import logging
import json
from entry import *


class Collection(Entry):
    def __init__(self, entryNode=None):
        if entryNode == None:
            return
        super(Collection, self).__init__(entryNode)
        self.libraryUrlIdentifier = ''
        self.collectionKey = entryNode.getElementsByTagName('zapi:key').item(0).childNodes.item(0).nodeValue
        self.numCollections = entryNode.getElementsByTagName('zapi:numCollections').item(0).childNodes.item(0).nodeValue
        self.numItems = entryNode.getElementsByTagName('zapi:numItems').item(0).childNodes.item(0).nodeValue

        contentNode = entryNode.getElementsByTagName('content').item(0)
        contentType = self.contentType
        if contentType == 'application/json':
            self.contentArray = json.loads(contentNode.childNodes.item(0).nodeValue)
            self.etag = contentNode.getAttribute('etag')
            self.parentCollectionKey = self.contentArray['parent']
            self.name = self.contentArray['name']



import logging
from item import *


class Items(object):
    def __init__(self):
        self.itemObjects = {}

    def __len__(self):
        return len(self.itemObjects)

    def __getitem__(self, itemKey):
        if itemKey in self.itemObjects:
            return self.itemObjects[itemKey]
        else:
            raise KeyError

    def __setitem__(self, itemKey, item):
        self.itemObjects[itemKey] = item

    def __delitem__(self, itemKey):
        del self.itemObjects[itemKey]

    def __iter__(self):
        return self.itemObjects.__iter__()

    def __reversed__(self):
        ritems = Items()
        ritems.itemObjects = self.itemObjects.reversed()
        return ritems

    def __contains__(self, itemKey):
        return itemKey in self.itemObjects

    def getItem(self, itemKey):
        if itemKey in self.itemObjects:
            return self.itemObjects[itemKey]
        else:
            return None

    def addItem(self, item):
        itemKey = item.itemKey
        self.itemObjects[itemKey] = item
        return item

    def addItemsFromFeed(self, feed):
        addedItems = []
        for entry in feed.entries:
            item = Item(entry)
            self.addItem(item)
            addedItems.append(item)
        return addedItems

    def replaceItem(self, item):
        itemKey = item.itemKey
        self.itemObjects[itemKey] = item
